@@ -25,13 +25,13 @@ app = Starlite(route_handlers=[example_handler], on_app_init=[ConfigureApp()])
 from . import (
     cache,
     compression,
+    db,
     dependencies,
     dto,
     exceptions,
     health,
     log,
     openapi,
-    orm,
     redis,
     repository,
     sentry,
@@ -47,13 +47,13 @@ __all__ = [
     "PluginConfig",
     "cache",
     "compression",
+    "db",
     "dependencies",
     "dto",
     "exceptions",
     "health",
     "log",
     "openapi",
-    "orm",
     "redis",
     "repository",
     "sentry",
@@ -63,4 +63,4 @@ __all__ = [
     "worker",
 ]
 
-__version__ = "0.4.0"
+__version__ = "0.5.0"
